@@ -1252,7 +1252,7 @@ bl_mdGetDiffString(char *MD) {
 
 char*
 cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned char rev, char brief) {
-  Uint i, j, k, q=0, p=0, cur=0, strsize, steps, msteps;
+  Uint i, j, k, q=0, p=0, cur=0, strsize, steps=0, msteps;
   char *cigarstr;
   char eopc=0;
 
@@ -1266,10 +1266,9 @@ cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned
     cur+=strsize;
   }
 
-  for(k=0; k < al->numofmeops; k++) {
+  for(steps=0, k=0; k < al->numofmeops; k++) {
     i = (rev) ? al->numofmeops - k - 1 : k;
-    //if Replacement occured
-    steps=0;
+    //if Replacement occured 
     if (al->meops[i].eop == Replacement) {
       //iter over all steps
       msteps=0;
@@ -1299,7 +1298,7 @@ cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned
         msteps++;
       }
 
-      steps = msteps;
+      steps += msteps;
       //set string ptrs
       p+=j;
       q+=j;
@@ -1311,7 +1310,8 @@ cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned
       else
         eopc = '=';
       //set ptrs
-      steps = al->meops[i].steps;
+      //steps = al->meops[i].steps;
+      steps += al->meops[i].steps;
       p+=steps;
       q+=steps;
     }
@@ -1322,11 +1322,22 @@ cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned
       else
         eopc = 'X';
       //set ptrs
-      steps = al->meops[i].steps;
+      //steps = al->meops[i].steps;
+      steps += al->meops[i].steps;
       p+=steps;
       q+=steps;
     }
 
+    //dump previous matches and mismatches if in brief mode
+    //if a different operation is coming
+    if(brief && steps && eopc == 'M' && 
+        al->meops[i].eop != Match && al->meops[i].eop != Mismatch) {
+      
+      strsize = snprintf(NULL, 0, "%d", steps)+1;
+      sprintf(&cigarstr[cur], "%d%c", steps, eopc);
+      cur+=strsize;
+      steps = 0;
+    }
 
     //if deletion occured
     if (al->meops[i].eop == Deletion) {
@@ -1355,11 +1366,15 @@ cigarstring(Alignment *al, Uint leftclip, Uint rightclip, char clipch, unsigned
       //     p+=steps; no moves!
     }
 
-
-    //strsize = floor(log(steps)/log(10))+2;
-    strsize = snprintf(NULL, 0, "%d", steps)+1;
-    sprintf(&cigarstr[cur], "%d%c", steps, eopc);
-    cur+=strsize;
+    //dump everything except "M"s in the brief mode
+    //unless we are at the end
+    if(eopc != 'M' || k+1 == al->numofmeops) {
+      //strsize = floor(log(steps)/log(10))+2;
+      strsize = snprintf(NULL, 0, "%d", steps)+1;
+      sprintf(&cigarstr[cur], "%d%c", steps, eopc);
+      cur+=strsize;
+      steps = 0;
+    }
   }
 
   if(rightclip || (leftclip && rev)) {
