@@ -57,7 +57,10 @@
  *   
  */
 
-samrec_t* bl_samInitRec(samrec_t *samrec, char *qname) {
+samrec_t* bl_samInitRec(samrec_t *samrec, char *qname, char fullname) {
+
+  char *tmp;
+  Uint len=0;
 
   samrec->qname = NULL;
   samrec->flag = 0;
@@ -73,7 +76,15 @@ samrec_t* bl_samInitRec(samrec_t *samrec, char *qname) {
   samrec->nooftags = 0;
   samrec->tags = NULL;
 
-  samrec->qname = bl_strdup(qname);
+  if(fullname) {
+    tmp = bl_strdup(qname);
+  } else {
+    len = strlen(qname);
+    tmp = strclip(NULL, qname, &len);
+  }
+
+  samrec->qname = tmp; 
+    
   return samrec;
 }
 
@@ -1339,7 +1350,7 @@ bl_samprintEmptyAlign (char *desc, char* seq, char* qual, char hasPaired,
   }
 
 
-  bl_samInitRec(&samlist->recs[0], desc);
+  bl_samInitRec(&samlist->recs[0], desc, nfo->fullname);
 
   if(!hasPaired) {
     nomatemapped = 0;
@@ -1426,7 +1437,7 @@ bl_samline2rec(char *line, Uint len, samheader_t *head) {
     switch(i+1) {
       case 1:
         qname = cur;
-        rec = bl_samInitRec(rec, qname);
+        rec = bl_samInitRec(rec, qname, 1);
         break;
       case 2: 
         flag = atoi(cur);
@@ -1640,7 +1651,7 @@ samlist_t *bl_samgetSamList (fasta_t *reads, Uint id, mapping_t *l,
       bl_reconvertBisulfite(seq, strlen(seq), nfo->bisulfite);
     }
 
-    bl_samInitRec(&samlist->recs[i], bl_getMapFragQryDesc(&l->f[i]));
+    bl_samInitRec(&samlist->recs[i], bl_getMapFragQryDesc(&l->f[i]), nfo->fullname);
 
     //predict strand
     if(nfo->split) {
