@@ -595,6 +595,10 @@ int main(int argc, char** argv) {
       "show alignments", NULL, NULL, &info.align);
   manopt(&optset, FLAG, 0, 0, "nohead",
       "do not output header", NULL, NULL, &info.nohead);
+
+  manopt(&optset, FLAG, 0, 'f', "fullname",
+      "write full query name (no trunctation at whitespace)", NULL, NULL, &info.fullname);
+
   //manopt(&optset, FLAG, 0, 'z', "nosuflinks",
   //    "dont use suflinks (does not affect index construction, for short reads only, increases runtime!)", NULL, NULL, &info.nosuflinks);
   /*  
